<?php

namespace App\Http\Swagger;

/**
 * 
 * @OA\Post(
 *      path="/api/ama/ndc_travel_order_create",
 *      summary="NDC - Travel Order Create",
 *      tags={"NDC"},
 *      description="Travel order create for selected offer.",
 *      @OA\RequestBody(
 *          required=true,
 *          @OA\JsonContent(
 *              type="object",
 *              @OA\Property(
 *                  property="PricingResponseID",
 *                  type="string",
 *                  example="SP2F-1952803286450754438",
 *                  description="'ShoppingResponse' ID in the Pricing Response."
 *              ),
 *              @OA\Property(
 *                  property="PricingOwnerCode",
 *                  type="string",
 *                  example="SQ",
 *                  description="'OwnerCode' of the Priced Offer or Upsell Offer."
 *              ),
 *              @OA\Property(
 *                  property="PricingOfferID",
 *                  type="string",
 *                  example="TOTYgMOOWaTtSj82d5mU34KA.1_1A_a05569b7-4a6b-4828-8c1b-23be9d55f7de_1A_1A_TPID_Ch4SGlNQMUYtMzc0NzAwMzEzNDY3NTg3NjgwNy0xGAE=",
 *                  description="'OfferID' of the selected offer."
 *              ),
 *              @OA\Property(
 *                  property="OfferItem",
 *                  type="object",
 *                  @OA\Property(
 *                      property="OfferItemID",
 *                      type="object"
 *                  ),
 *                  @OA\Property(
 *                      property="MandatoryInd",
 *                      type="object"
 *                  ),
 *                  @OA\Property(
 *                      property="FareDetail",
 *                      type="object"
 *                  ),
 *                  @OA\Property(
 *                      property="Service",
 *                      type="object"
 *                  ),
 *                  @OA\Property(
 *                      property="Price",
 *                      type="object"
 *                  ),
 *                  description="This is the OfferItem object received from 'TravelOfferPrice' as 'PricedOffer' or 'Other Upsell Offers'"
 *              ),
 * 
 *                @OA\Property(
 *                   property="PaxList",
 *                   type="array",
 *                   @OA\Items(
 *                      type="object",
 *                      @OA\Property(
 *                         type="object",
 *                         @OA\Property(
 *                            property="PaxID",
 *                            type="object",
 *                            example={"value": "P1"}
 *                         ),
 *                         @OA\Property(
 *                            property="PTC",
 *                            type="object",
 *                            example={"value": "P1"}
 *                         ),
 *                      )
 *                   ),
 *                   description="Pax reference identifiers",
 *                   example={
 *                      {
 *                         "PaxID": {"value": "P1"},
 *                         "PTC": {"value": "ADT"}
 *                      },
 *                      {
 *                         "PaxID": {"value": "P2"},
 *                         "PTC": {"value": "ADT"}
 *                      }
 *                   }
 *                ),
 *                @OA\Property(
 *                   property="Travellers",
 *                   type="array",
 *                   @OA\Items(ref="#/components/schemas/Traveler")
 *                )
 * 
 *          )
 *      ),
 *      @OA\Response(
 *          response=200,
 *          description="Successful operation",
 *          @OA\JsonContent(
 *              type="object",
 *              @OA\Property(
 *                  property="amaReply", 
 *                  type="object", 
 * 
 *                   @OA\Property(
 *                      property="Response",
 *                      type="array",
 *                      @OA\Items(
 *                         type="object",
 *                         @OA\Property(
 *                            property="DataLists",
 *                            type="object"
 *                         ),
 *                         @OA\Property(
 *                            property="Metadata",
 *                            type="object"
 *                         ),
 *                         @OA\Property(
 *                            property="Order",
 *                            type="object",
 *                            @OA\Property(property="OrderID", type="object"),
 *                            @OA\Property(property="OwnerCode", type="object"),
 *                            @OA\Property(property="PaymentTimeLimitDateTime", type="object"),
 *                            @OA\Property(property="BookingRef", type="object"),
 *                            @OA\Property(property="OrderItem", type="object"),
 *                            @OA\Property(property="TotalPrice", type="object")
 *                         ),
 *                         @OA\Property(
 *                            property="Warning",
 *                            type="object"
 *                         )
 *                      ),
 *                   ),
 *                  
 *              )
 *          )
 *      ),
 *      @OA\Response(
 *          response=400,
 *          description="Bad Request",
 *          @OA\JsonContent(
 *              type="object",
 *              @OA\Property(property="error_message", type="string")
 *          )
 *      )
 * )
 */

class NDC_3TravelOrderCreate
{
   //
}
